==> micropython-1.17.tar.xz: micropython-1.17/lib/asf4/samd51/hri/hri_d51.h <==
/**
 * \file
 *
 * \brief SAM D51 HRI top-level header file
 *
 * Copyright (C) 2016 Atmel Corporation. All rights reserved.
 *
 * \asf_license_start
 *
 * \page License
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. The name of Atmel may not be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * 4. This software may only be redistributed and used in connection with an
 *    Atmel microcontroller product.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * EXPRESSLY AND SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * \asf_license_stop
 */

#ifndef _HRI_D51_H_INCLUDED_
#define _HRI_D51_H_INCLUDED_

#include <sam.h>
#include <hri_ac_d51.h>
#include <hri_adc_d51.h>
#include <hri_aes_d51.h>
#include <hri_ccl_d51.h>
#include <hri_cmcc_d51.h>
#include <hri_dac_d51.h>
#include <hri_dmac_d51.h>
#include <hri_dsu_d51.h>
#include <hri_eic_d51.h>
#include <hri_evsys_d51.h>
#include <hri_freqm_d51.h>
#include <hri_gclk_d51.h>
#include <hri_hmatrixb_d51.h>
#include <hri_i2s_d51.h>
#include <hri_icm_d51.h>
#include <hri_mclk_d51.h>
#include <hri_nvmctrl_d51.h>
#include <hri_osc32kctrl_d51.h>
#include <hri_oscctrl_d51.h>
#include <hri_pac_d51.h>
#include <hri_pcc_d51.h>
#include <hri_pdec_d51.h>
#include <hri_pm_d51.h>
#include <hri_port_d51.h>
#include <hri_qspi_d51.h>
#include <hri_ramecc_d51.h>
#include <hri_rstc_d51.h>
#include <hri_rtc_d51.h>
#include <hri_sdhc_d51.h>
#include <hri_sercom_d51.h>
#include <hri_supc_d51.h>
#include <hri_tal_d51.h>
#include <hri_tc_d51.h>
#include <hri_tcc_d51.h>
#include <hri_trng_d51.h>
#include <hri_usb_d51.h>
#include <hri_wdt_d51.h>

#endif /* _HRI_D51_H_INCLUDED_ */

==> micropython-1.25.0.tar.xz: micropython-1.25.0/lib/asf4/samd51/hri/hri_d51.h <==
/**
 * \file
 *
 * \brief SAM D51 HRI top-level header file
 *
 * Copyright (C) 2016 Atmel Corporation. All rights reserved.
 *
 * \asf_license_start
 *
 * \page License
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. The name of Atmel may not be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * 4. This software may only be redistributed and used in connection with an
 *    Atmel microcontroller product.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * EXPRESSLY AND SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * \asf_license_stop
 */

#ifndef _HRI_D51_H_INCLUDED_
#define _HRI_D51_H_INCLUDED_

#include <sam.h>
// #include <hri_ac_d51.h>
#include <hri_adc_d51.h>
// #include <hri_aes_d51.h>
// #include <hri_ccl_d51.h>
// #include <hri_cmcc_d51.h>
#include <hri_dac_d51.h>
#include <hri_dmac_d51.h>
#include <hri_dsu_d51.h>
// #include <hri_eic_d51.h>
#include <hri_evsys_d51.h>
// #include <hri_freqm_d51.h>
#include <hri_gclk_d51.h>
// #include <hri_hmatrixb_d51.h>
// #include <hri_i2s_d51.h>
#include <hri_icm_d51.h>
#include <hri_mclk_d51.h>
#include <hri_nvmctrl_d51.h>
#include <hri_osc32kctrl_d51.h>
#include <hri_oscctrl_d51.h>
// #include <hri_pac_d51.h>
// #include <hri_pcc_d51.h>
// #include <hri_pdec_d51.h>
#include <hri_pm_d51.h>
#include <hri_port_d51.h>
// #include <hri_qspi_d51.h>
// #include <hri_ramecc_d51.h>
#include <hri_rstc_d51.h>
#include <hri_rtc_d51.h>
// #include <hri_sdhc_d51.h>
#include <hri_sercom_d51.h>
#include <hri_supc_d51.h>
// #include <hri_tal_d51.h>
// #include <hri_tc_d51.h>
// #include <hri_tcc_d51.h>
#include <hri_trng_d51.h>
// #include <hri_usb_d51.h>
#include <hri_wdt_d51.h>

#endif /* _HRI_D51_H_INCLUDED_ */
